from typing import overload
from typing import List
from typing import TypeVar
from .BlockStateHelper import BlockStateHelper
from .DirectionHelper import DirectionHelper

net_minecraft_block_BlockState = TypeVar("net_minecraft_block_BlockState")
BlockState = net_minecraft_block_BlockState


class UniversalBlockStateHelper(BlockStateHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: BlockState) -> None:
		pass

	@overload
	def getAttachment(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getEastWallShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getNorthWallShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getSouthWallShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getWestWallShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getEastWireConnection(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getNorthWireConnection(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getSouthWireConnection(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getWestWireConnection(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getBlockHalf(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getDoubleBlockHalf(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getRailShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getStraightRailShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getOrientation(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getHorizontalAxis(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getAxis(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getHorizontalFacing(self) -> DirectionHelper:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getHopperFacing(self) -> DirectionHelper:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getFacing(self) -> DirectionHelper:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isUp(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isDown(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isNorth(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSouth(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isEast(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isWest(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getHoneyLevel(self) -> int:
		"""Used on beehives.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isBottom(self) -> bool:
		"""Used on scaffolding.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isBubbleColumnDown(self) -> bool:
		"""Used on bubble columns.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isBubbleColumnUp(self) -> bool:
		"""Used on bubble columns.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isAttached(self) -> bool:
		"""Used on trip wire hooks.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isDisarmed(self) -> bool:
		"""Used on trip wires.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isConditional(self) -> bool:
		"""Used on command blocks.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isEnabled(self) -> bool:
		"""Used on hoppers.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isExtended(self) -> bool:
		"""Used on pistons.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isShort(self) -> bool:
		"""Used on piston heads.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasEye(self) -> bool:
		"""Used on end portal frames.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isFalling(self) -> bool:
		"""Used on fluids.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getLevel(self) -> int:
		"""Used on fluids and stuff\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getMaxLevel(self) -> int:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getMinLevel(self) -> int:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isHanging(self) -> bool:
		"""Used on lanterns.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasBottle0(self) -> bool:
		"""Used on brewing stands.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasBottle1(self) -> bool:
		"""Used on brewing stands.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasBottle2(self) -> bool:
		"""Used on brewing stands.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasRecord(self) -> bool:
		"""Used on jukeboxes.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasBook(self) -> bool:
		"""Used on lecterns.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isInverted(self) -> bool:
		"""Used on daylight sensors.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isInWall(self) -> bool:
		"""Used on fence gates.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isOpen(self) -> bool:
		"""Used on fence gates, barrels, trap doors and doors.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isLit(self) -> bool:
		"""Used on candles, all types of furnaces, campfires and redstone torches.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isLocked(self) -> bool:
		"""Used on repeaters.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getDelay(self) -> int:
		"""Used on repeaters.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isOccupied(self) -> bool:
		"""Used on beds.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isPersistent(self) -> bool:
		"""Used on leaves.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getDistance(self) -> int:
		"""Used on leaves and scaffold.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getMaxDistance(self) -> int:
		"""Used on leaves and scaffold.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getMinDistance(self) -> int:
		"""Used on leaves and scaffold.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isPowered(self) -> bool:
		"""Used on bells, buttons, detector rails, diodes, doors, fence gates, lecterns, levers,
lightning rods, note blocks, observers, powered rails, pressure plates, trap doors, trip wire
hooks and trip wires.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSignalFire(self) -> bool:
		"""Used on campfires.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSnowy(self) -> bool:
		"""Used on snowy dirt blocks.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isTriggered(self) -> bool:
		"""Used on dispensers.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isUnstable(self) -> bool:
		"""Used on tnt.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isWaterlogged(self) -> bool:
		"""Used on amethysts, corals, rails, dripleaves, dripleaf stems, campfires, candles, chains,
chests, conduits, fences, double plants, ender chests, iron bars, glass panes, glow lichen,
hanging roots, ladders, lanterns, light blocks, lightning rods, pointed dripstone,
scaffolding , sculk sensors, sea pickles, signs, stairs, slabs, trap doors and walls\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getBedPart(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getDoorHinge(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getInstrument(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getPistonType(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getSlabType(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getStairShape(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getStructureBlockMode(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getBambooLeaves(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getTilt(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getVerticalDirection(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getThickness(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getChestType(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getComparatorMode(self) -> str:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def hasBerries(self) -> bool:
		"""Used on cave vine roots.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getAge(self) -> int:
		"""crop age and such\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getMaxAge(self) -> int:
		pass

	@overload
	def getBites(self) -> int:
		"""Used on cakes.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getCandles(self) -> int:
		"""Used on candles.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getEggs(self) -> int:
		"""Used on turtle eggs.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getHatched(self) -> int:
		"""Used on turtle eggs.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getLayers(self) -> int:
		"""Used on snow layers.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getMoisture(self) -> int:
		"""Used on farmland.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getNote(self) -> int:
		"""Used on note blocks.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getPickles(self) -> int:
		"""Used on sea pickles.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getPower(self) -> int:
		"""Used on daylight sensors, redstone wires, sculk sensors, target blocks, weighted pressure
plates.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getStage(self) -> int:
		"""Used on bamboo, saplings.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getCharges(self) -> int:
		"""Used on respawn anchors.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isShrieking(self) -> bool:
		"""Used on sculk sensors.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def canSummon(self) -> bool:
		"""Used on sculk sensors.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def getSculkSensorPhase(self) -> str:
		"""Used on sculk sensors.\n
		Since: 1.8.4 
		"""
		pass

	@overload
	def isBloom(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getRotation(self) -> int:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSlot0Occupied(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSlot1Occupied(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSlot2Occupied(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSlot3Occupied(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSlot4Occupied(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def isSlot5Occupied(self) -> bool:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def getFlowerAmount(self) -> int:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def getBlockFace(self) -> str:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def getDusted(self) -> int:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def isCracked(self) -> bool:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def main(self, args: List[str]) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .HitResultHelper import HitResultHelper
from .DirectionHelper import DirectionHelper
from .BlockPosHelper import BlockPosHelper

net_minecraft_util_hit_BlockHitResult = TypeVar("net_minecraft_util_hit_BlockHitResult")
BlockHitResult = net_minecraft_util_hit_BlockHitResult


class HitResultHelper_Block(HitResultHelper):

	@overload
	def __init__(self, base: BlockHitResult) -> None:
		pass

	@overload
	def getSide(self) -> DirectionHelper:
		pass

	@overload
	def getBlockPos(self) -> BlockPosHelper:
		pass

	@overload
	def isMissed(self) -> bool:
		pass

	@overload
	def isInsideBlock(self) -> bool:
		pass

	@overload
	def asBlock(self) -> "HitResultHelper_Block":
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_projectile_FishingBobberEntity = TypeVar("net_minecraft_entity_projectile_FishingBobberEntity")
FishingBobberEntity = net_minecraft_entity_projectile_FishingBobberEntity


class FishingBobberEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FishingBobberEntity) -> None:
		pass

	@overload
	def hasCaughtFish(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if a fish has been caught, 'false' otherwise. 
		"""
		pass

	@overload
	def isInOpenWater(self) -> bool:
		"""When in open water the player can get treasures from fishing.\n
		Since: 1.8.4 

		Returns:
			'true' if the bobber is in open water, 'false' otherwise. 
		"""
		pass

	@overload
	def hasEntityHooked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the bobber has an entity hooked, 'false' otherwise. 
		"""
		pass

	@overload
	def getHookedEntity(self) -> EntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the hooked entity, or 'null' if there is no entity hooked. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import Mapping
from typing import Set
from .BaseLibrary import BaseLibrary
from .IDraw2D import IDraw2D
from .Draw3D import Draw3D
from .ScriptScreen import ScriptScreen
from .IScreen import IScreen
from .CustomImage import CustomImage
from .Draw2D import Draw2D


class FHud(BaseLibrary):
	"""Functions for displaying stuff in 2 to 3 dimensions 
An instance of this class is passed to scripts as the 'Hud' variable.\n
	Since: 1.0.5 
	"""
	overlays: Set[IDraw2D]
	renders: Set[Draw3D]

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def createScreen(self, title: str, dirtBG: bool) -> ScriptScreen:
		"""
		Since: 1.0.5 

		Args:
			title: 
			dirtBG: boolean of whether to use a dirt background or not. 

		Returns:
			a new IScreen Object. 
		"""
		pass

	@overload
	def openScreen(self, s: IScreen) -> None:
		"""Opens a IScreen Object.\n
		Since: 1.0.5 

		Args:
			s: 
		"""
		pass

	@overload
	def getOpenScreen(self) -> IScreen:
		"""
		Since: 1.2.7 

		Returns:
			the currently open Screen as an IScreen 
		"""
		pass

	@overload
	def createTexture(self, width: int, height: int, name: str) -> CustomImage:
		"""
		Since: 1.8.4 

		Args:
			width: the width of the canvas 
			height: the height of the canvas 

		Returns:
			a CustomImage that can be used as a texture for screen backgrounds, rendering
images, etc. 
		"""
		pass

	@overload
	def createTexture(self, path: str, name: str) -> CustomImage:
		"""
		Since: 1.8.4 

		Args:
			path: absolute path to an image file 

		Returns:
			a CustomImage that can be used as a texture for screen backgrounds, rendering
images, etc. 
		"""
		pass

	@overload
	def getRegisteredTextures(self) -> Mapping[str, CustomImage]:
		"""
		Since: 1.8.4 

		Returns:
			an immutable Map of all registered custom textures. 
		"""
		pass

	@overload
	def getScaleFactor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current gui scale factor of minecraft. 
		"""
		pass

	@overload
	def getOpenScreenName(self) -> str:
		"""
		Since: 1.0.5, renamed from 'getOpenScreen' in 1.2.7 

		Returns:
			The name of the currently open screen. 
		"""
		pass

	@overload
	def isContainer(self) -> bool:
		"""
		Since: 1.1.2 

		Returns:
			a Boolean denoting if the currently open screen is a container. 
		"""
		pass

	@overload
	def createDraw2D(self) -> Draw2D:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def registerDraw2D(self, overlay: IDraw2D) -> None:
		"""
		Since: 1.0.5 
Registers an IDraw2D to be rendered. 

		Args:
			overlay: 
		"""
		pass

	@overload
	def unregisterDraw2D(self, overlay: IDraw2D) -> None:
		"""
		Since: 1.0.5 
Unregisters an IDraw2D to stop it being rendered. 

		Args:
			overlay: 
		"""
		pass

	@overload
	def listDraw2Ds(self) -> List[IDraw2D]:
		"""
		Since: 1.0.5 

		Returns:
			A list of current IDraw2D . 
		"""
		pass

	@overload
	def clearDraw2Ds(self) -> None:
		"""
		Since: 1.0.5 
clears the Draw2D render list. 
		"""
		pass

	@overload
	def createDraw3D(self) -> Draw3D:
		"""
		Since: 1.0.6 

		Returns:
			a new Draw3D . 
		"""
		pass

	@overload
	def registerDraw3D(self, draw: Draw3D) -> None:
		"""
		Since: 1.0.6 
Registers an Draw3D to be rendered. 

		Args:
			draw: 
		"""
		pass

	@overload
	def unregisterDraw3D(self, draw: Draw3D) -> None:
		"""
		Since: 1.0.6 
Unregisters an Draw3D to stop it being rendered. 

		Args:
			draw: 
		"""
		pass

	@overload
	def listDraw3Ds(self) -> List[Draw3D]:
		"""
		Since: 1.0.6 

		Returns:
			A list of current Draw3D . 
		"""
		pass

	@overload
	def clearDraw3Ds(self) -> None:
		"""
		Since: 1.0.6 
clears the Draw3D render list. 
		"""
		pass

	@overload
	def getMouseX(self) -> float:
		"""
		Since: 1.1.3 

		Returns:
			the current X coordinate of the mouse 
		"""
		pass

	@overload
	def getMouseY(self) -> float:
		"""
		Since: 1.1.3 

		Returns:
			the current Y coordinate of the mouse 
		"""
		pass

	@overload
	def getWindowWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current window width. 
		"""
		pass

	@overload
	def getWindowHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the current window height. 
		"""
		pass

	pass





from setuptools import setup, find_packages
from os import path
import os
import time

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


VERSION = '1.9.2'
if "-" in VERSION: VERSION = VERSION.split("-")[0]
VERSION += "." + str(time.time()).split(".")[0][3:]
DESCRIPTION = 'A package to let your IDE know what JsMacros can do'

def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths

extra_files = package_files('JsMacrosAC')

# Setting up
setup(
    name="JsMacrosAC",
    version=VERSION,
    author="Hasenzahn1",
    author_email="<motzer10@gmx.de>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=["JsMacrosAC"],
    package_data = {"": extra_files},
    install_requires=[],
    keywords=['python', 'JsMacros', 'Autocomplete', 'Doc'],
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


from typing import overload
from typing import TypeVar

net_minecraft_network_packet_s2c_play_ScreenHandlerSlotUpdateS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_ScreenHandlerSlotUpdateS2CPacket")
ScreenHandlerSlotUpdateS2CPacket = net_minecraft_network_packet_s2c_play_ScreenHandlerSlotUpdateS2CPacket

net_minecraft_network_packet_s2c_play_BlockUpdateS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_BlockUpdateS2CPacket")
BlockUpdateS2CPacket = net_minecraft_network_packet_s2c_play_BlockUpdateS2CPacket

net_minecraft_network_packet_s2c_play_BlockEntityUpdateS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_BlockEntityUpdateS2CPacket")
BlockEntityUpdateS2CPacket = net_minecraft_network_packet_s2c_play_BlockEntityUpdateS2CPacket

net_minecraft_network_packet_s2c_play_PlayerListS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_PlayerListS2CPacket")
PlayerListS2CPacket = net_minecraft_network_packet_s2c_play_PlayerListS2CPacket

net_minecraft_network_packet_s2c_play_PlayerRemoveS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_PlayerRemoveS2CPacket")
PlayerRemoveS2CPacket = net_minecraft_network_packet_s2c_play_PlayerRemoveS2CPacket

net_minecraft_client_network_ClientCommonNetworkHandler = TypeVar("net_minecraft_client_network_ClientCommonNetworkHandler")
ClientCommonNetworkHandler = net_minecraft_client_network_ClientCommonNetworkHandler

net_minecraft_network_packet_s2c_play_ChunkDataS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_ChunkDataS2CPacket")
ChunkDataS2CPacket = net_minecraft_network_packet_s2c_play_ChunkDataS2CPacket

net_minecraft_network_packet_s2c_play_InventoryS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_InventoryS2CPacket")
InventoryS2CPacket = net_minecraft_network_packet_s2c_play_InventoryS2CPacket

net_minecraft_client_network_PlayerListEntry = TypeVar("net_minecraft_client_network_PlayerListEntry")
PlayerListEntry = net_minecraft_client_network_PlayerListEntry

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

net_minecraft_network_packet_s2c_play_ItemPickupAnimationS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_ItemPickupAnimationS2CPacket")
ItemPickupAnimationS2CPacket = net_minecraft_network_packet_s2c_play_ItemPickupAnimationS2CPacket

net_minecraft_network_packet_s2c_play_EntityStatusEffectS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_EntityStatusEffectS2CPacket")
EntityStatusEffectS2CPacket = net_minecraft_network_packet_s2c_play_EntityStatusEffectS2CPacket

net_minecraft_network_packet_s2c_play_PlayerListS2CPacket_Entry = TypeVar("net_minecraft_network_packet_s2c_play_PlayerListS2CPacket_Entry")
PlayerListS2CPacket_Entry = net_minecraft_network_packet_s2c_play_PlayerListS2CPacket_Entry

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_network_packet_s2c_play_GameJoinS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_GameJoinS2CPacket")
GameJoinS2CPacket = net_minecraft_network_packet_s2c_play_GameJoinS2CPacket

net_minecraft_network_packet_s2c_play_RemoveEntityStatusEffectS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_RemoveEntityStatusEffectS2CPacket")
RemoveEntityStatusEffectS2CPacket = net_minecraft_network_packet_s2c_play_RemoveEntityStatusEffectS2CPacket

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID

net_minecraft_network_packet_s2c_play_UnloadChunkS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_UnloadChunkS2CPacket")
UnloadChunkS2CPacket = net_minecraft_network_packet_s2c_play_UnloadChunkS2CPacket

net_minecraft_network_packet_s2c_play_ChunkDeltaUpdateS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_ChunkDeltaUpdateS2CPacket")
ChunkDeltaUpdateS2CPacket = net_minecraft_network_packet_s2c_play_ChunkDeltaUpdateS2CPacket

net_minecraft_network_packet_s2c_play_BossBarS2CPacket = TypeVar("net_minecraft_network_packet_s2c_play_BossBarS2CPacket")
BossBarS2CPacket = net_minecraft_network_packet_s2c_play_BossBarS2CPacket


class MixinClientPlayNetworkHandler(ClientCommonNetworkHandler):

	@overload
	def onPlayerList(self, packet: PlayerListS2CPacket, ci: CallbackInfo, var2: iter, entry: PlayerListS2CPacket_Entry, playerListEntry: PlayerListEntry) -> None:
		pass

	@overload
	def onPlayerListEnd(self, packet: PlayerRemoveS2CPacket, ci: CallbackInfo, var2: iter, uUID: UUID, playerListEntry: PlayerListEntry) -> None:
		pass

	@overload
	def onTitle(self, title: Text) -> Text:
		pass

	@overload
	def onSubtitle(self, title: Text) -> Text:
		pass

	@overload
	def onBossBar(self, packet: BossBarS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onItemPickupAnimation(self, packet: ItemPickupAnimationS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onGameJoin(self, packet: GameJoinS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onChunkData(self, packet: ChunkDataS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onBlockUpdate(self, packet: BlockUpdateS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onChunkDeltaUpdate(self, packet: ChunkDeltaUpdateS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onBlockEntityUpdate(self, packet: BlockEntityUpdateS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onUnloadChunk(self, packet: UnloadChunkS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onEntityStatusEffect(self, packet: EntityStatusEffectS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onEntityStatusEffect(self, packet: RemoveEntityStatusEffectS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onHeldSlotUpdate(self, packet: ScreenHandlerSlotUpdateS2CPacket, ci: CallbackInfo) -> None:
		pass

	@overload
	def onInventorySlotUpdate(self, packet: ScreenHandlerSlotUpdateS2CPacket, ci: CallbackInfo) -> None:
		pass

	@overload
	def onScreenSlotUpdate(self, packet: ScreenHandlerSlotUpdateS2CPacket, ci: CallbackInfo) -> None:
		pass

	@overload
	def onScreenSlotUpdate2(self, packet: ScreenHandlerSlotUpdateS2CPacket, ci: CallbackInfo) -> None:
		pass

	@overload
	def onInventoryUpdate(self, packet: InventoryS2CPacket, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .FormattingHelper import FormattingHelper
from .ScoreboardsHelper import ScoreboardsHelper

net_minecraft_scoreboard_Team = TypeVar("net_minecraft_scoreboard_Team")
Team = net_minecraft_scoreboard_Team


class TeamHelper(BaseHelper):
	"""
	Since: 1.3.0 
	"""

	@overload
	def __init__(self, t: Team) -> None:
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getDisplayName(self) -> TextHelper:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getPlayerList(self) -> List[str]:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getColorFormat(self) -> FormattingHelper:
		"""
		Since: 1.8.4 

		Returns:
			the formatting of this team's color. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getColorIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color index of this team. 
		"""
		pass

	@overload
	def getColorValue(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color value for this team or '-1' if it has no color. 
		"""
		pass

	@overload
	def getColorName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this team's color. 
		"""
		pass

	@overload
	def getScoreboard(self) -> ScoreboardsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the scoreboard including this team. 
		"""
		pass

	@overload
	def getPrefix(self) -> TextHelper:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getSuffix(self) -> TextHelper:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getCollisionRule(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def isFriendlyFire(self) -> bool:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def showFriendlyInvisibles(self) -> bool:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def nametagVisibility(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def deathMessageVisibility(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper
from .RecipeHelper import RecipeHelper

T = TypeVar("T")

class RecipeInventory(Generic[T], Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the output item. 
		"""
		pass

	@overload
	def getInputSize(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum input size for all recipes in this inventory. 
		"""
		pass

	@overload
	def getInput(self, x: int, z: int) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the input slot, starting at 0, left to right. Must be less than RecipeInventory#getCraftingWidth() 
			z: the z position of the input slot, starting at 0, top to bottom. Must be less than RecipeInventory#getCraftingHeight() 

		Returns:
			the input item at the given position. 
		"""
		pass

	@overload
	def getInput(self) -> List[List[ItemStackHelper]]:
		"""
		Since: 1.8.4 

		Returns:
			the input items of the crafting grid, in a 2d array. 
		"""
		pass

	@overload
	def getCraftingWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the crafting grid. 
		"""
		pass

	@overload
	def getCraftingHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the crafting grid. 
		"""
		pass

	@overload
	def getCraftingSlotCount(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of slots used for crafting. 
		"""
		pass

	@overload
	def getCategory(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the recipe category of recipes that can be crafted in this inventory. 
		"""
		pass

	@overload
	def getCraftableRecipes(self) -> List[RecipeHelper]:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def getRecipes(self, craftable: bool) -> List[RecipeHelper]:
		"""
		Since: 1.8.4 

		Args:
			craftable: whether only to list craftable recipes 

		Returns:
			a list of recipes that can be crafted in this inventory. 
		"""
		pass

	@overload
	def isRecipeBookOpened(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the recipe book is visible, 'false' otherwise. 
		"""
		pass

	@overload
	def toggleRecipeBook(self) -> None:
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def setRecipeBook(self, open: bool) -> None:
		"""
		Since: 1.8.4 

		Args:
			open: whether to open or close the recipe book 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .BaseHelper import BaseHelper

T = TypeVar("T")

class ModContainerHelper(Generic[T], BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def getId(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the mod's id. 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the mod's name. 
		"""
		pass

	@overload
	def getDescription(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the mod's description. 
		"""
		pass

	@overload
	def getVersion(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the mod's version. 
		"""
		pass

	@overload
	def getEnv(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the environment this mod is intended for. 
		"""
		pass

	@overload
	def getAuthors(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all authors. 
		"""
		pass

	@overload
	def getDependencies(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all dependencies. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .BlockStateHelper import BlockStateHelper
from .FluidStateHelper import FluidStateHelper

net_minecraft_predicate_StatePredicate = TypeVar("net_minecraft_predicate_StatePredicate")
StatePredicate = net_minecraft_predicate_StatePredicate


class StatePredicateHelper(BaseHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: StatePredicate) -> None:
		pass

	@overload
	def test(self, state: BlockStateHelper) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def test(self, state: FluidStateHelper) -> bool:
		"""
		Since: 1.9.1 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_mob_CreeperEntity = TypeVar("net_minecraft_entity_mob_CreeperEntity")
CreeperEntity = net_minecraft_entity_mob_CreeperEntity


class CreeperEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: CreeperEntity) -> None:
		pass

	@overload
	def isCharged(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the creeper is charged, 'false' otherwise. 
		"""
		pass

	@overload
	def isIgnited(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the creeper has been ignited, 'false' otherwise. 
		"""
		pass

	@overload
	def getFuseChange(self) -> int:
		"""A negative value means the creeper is currently defusing, while a positive value means the
creeper is currently charging up.\n
		Since: 1.8.4 

		Returns:
			the change in fuse every tick. 
		"""
		pass

	@overload
	def getFuseTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the time the creeper has been charging up. 
		"""
		pass

	@overload
	def getMaxFuseTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum time the creeper can be charged for before exploding. 
		"""
		pass

	@overload
	def getRemainingFuseTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the remaining time until the creeper explodes with the current fuse time, or '-1' if the creeper is not about to explode. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .FishEntityHelper import FishEntityHelper

net_minecraft_entity_passive_TropicalFishEntity = TypeVar("net_minecraft_entity_passive_TropicalFishEntity")
TropicalFishEntity = net_minecraft_entity_passive_TropicalFishEntity


class TropicalFishEntityHelper(FishEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: TropicalFishEntity) -> None:
		pass

	@overload
	def getVariant(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this tropical fish. 
		"""
		pass

	@overload
	def getSize(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the size of this tropical fish's variant. 
		"""
		pass

	@overload
	def getBaseColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the base color of this tropical fish's pattern. 
		"""
		pass

	@overload
	def getPatternColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the pattern color of this tropical fish's pattern. 
		"""
		pass

	@overload
	def getVarietyId(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the id of this tropical fish's variant. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .BlockDataHelper import BlockDataHelper

net_minecraft_block_BlockState = TypeVar("net_minecraft_block_BlockState")
BlockState = net_minecraft_block_BlockState

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos

net_minecraft_block_entity_BlockEntity = TypeVar("net_minecraft_block_entity_BlockEntity")
BlockEntity = net_minecraft_block_entity_BlockEntity


class EventBlockUpdate(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	block: BlockDataHelper
	updateType: str

	@overload
	def __init__(self, block: BlockState, blockEntity: BlockEntity, blockPos: BlockPos, updateType: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .HitResultHelper import HitResultHelper
from .EntityHelper import EntityHelper

net_minecraft_util_hit_EntityHitResult = TypeVar("net_minecraft_util_hit_EntityHitResult")
EntityHitResult = net_minecraft_util_hit_EntityHitResult


class HitResultHelper_Entity(HitResultHelper):

	@overload
	def __init__(self, base: EntityHitResult) -> None:
		pass

	@overload
	def getEntity(self) -> EntityHelper:
		pass

	@overload
	def asEntity(self) -> "HitResultHelper_Entity":
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .Text import Text
from .Rect import Rect
from .Line import Line
from .Item import Item
from .Image import Image
from .Draw2DElement import Draw2DElement
from .RenderElement import RenderElement
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .Draw2D import Draw2D
from .Item_Builder import Item_Builder
from .Image_Builder import Image_Builder
from .Rect_Builder import Rect_Builder
from .Line_Builder import Line_Builder
from .Text_Builder import Text_Builder
from .Draw2DElement_Builder import Draw2DElement_Builder
from .MethodWrapper import MethodWrapper

T = TypeVar("T")
net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext


class IDraw2D:
	"""
	Since: 1.2.7 
	"""

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.2.7 

		Returns:
			screen width 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.2.7 

		Returns:
			screen height 
		"""
		pass

	@overload
	def getTexts(self) -> List[Text]:
		"""
		Since: 1.2.7 

		Returns:
			text elements 
		"""
		pass

	@overload
	def getRects(self) -> List[Rect]:
		"""
		Since: 1.2.7 

		Returns:
			rect elements 
		"""
		pass

	@overload
	def getLines(self) -> List[Line]:
		"""
		Since: 1.8.4 

		Returns:
			all registered line elements. 
		"""
		pass

	@overload
	def getItems(self) -> List[Item]:
		"""
		Since: 1.2.7 

		Returns:
			item elements 
		"""
		pass

	@overload
	def getImages(self) -> List[Image]:
		"""
		Since: 1.2.7 

		Returns:
			image elements 
		"""
		pass

	@overload
	def getDraw2Ds(self) -> List[Draw2DElement]:
		"""
		Since: 1.8.4 

		Returns:
			all registered draw2d elements. 
		"""
		pass

	@overload
	def getElements(self) -> List[RenderElement]:
		"""
		Since: 1.2.9 

		Returns:
			a read only copy of the list of all elements added by scripts. 
		"""
		pass

	@overload
	def removeElement(self, e: RenderElement) -> T:
		"""removes any element regardless of type.\n
		Since: 1.2.9 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def reAddElement(self, e: T) -> T:
		"""re-add an element you removed with IDraw2D#removeElement(xyz.wagyourtail.jsmacros.client.api.classes.render.components.RenderElement)\n
		Since: 1.2.9 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool) -> Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool) -> Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool) -> Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool) -> Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def removeText(self, t: Text) -> T:
		"""
		Since: 1.2.7 

		Args:
			t: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> Image:
		"""
		Since: 1.2.7 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			height: height on screen 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> Image:
		"""
		Since: 1.4.0 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			height: height on screen 
			zIndex: z-index 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.2.7 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			rotation: the rotation (clockwise) of the texture (as degrees) 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			height: height on screen 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.4.0 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			rotation: the rotation (clockwise) of the texture (as degrees) 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			height: height on screen 
			zIndex: z-index 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.6.5 

		Args:
			color: 
			imageY: 
			textureWidth: 
			imageX: 
			rotation: 
			regionWidth: 
			textureHeight: 
			x: 
			width: 
			y: 
			regionHeight: 
			id: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> Image:
		"""
		Since: 1.6.5 

		Args:
			color: 
			imageY: 
			textureWidth: 
			imageX: 
			rotation: 
			regionWidth: 
			textureHeight: 
			alpha: 
			x: 
			width: 
			y: 
			regionHeight: 
			id: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def removeImage(self, i: Image) -> T:
		"""
		Since: 1.2.7 

		Args:
			i: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> Rect:
		"""
		Since: 1.2.7 

		Args:
			color: as hex, with alpha channel 
			y1: 
			x1: 
			y2: 
			x2: 

		Returns:
			added rect 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> Rect:
		"""
		Since: 1.2.7 

		Args:
			color: as hex 
			alpha: alpha channel 0-255 
			y1: 
			x1: 
			y2: 
			x2: 

		Returns:
			added rect 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> Rect:
		"""
		Since: 1.2.7 

		Args:
			color: as hex 
			alpha: alpha channel 0-255 
			rotation: as degrees 
			y1: 
			x1: 
			y2: 
			x2: 

		Returns:
			added rect 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> Rect:
		"""
		Since: 1.4.0 

		Args:
			color: as hex 
			alpha: alpha channel 0-255 
			rotation: as degrees 
			y1: 
			x1: 
			y2: 
			x2: 
			zIndex: z-index 

		Returns:
			added rect 
		"""
		pass

	@overload
	def removeRect(self, r: Rect) -> T:
		"""
		Since: 1.2.7 

		Args:
			r: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int) -> Line:
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line, can include alpha value 
			y1: the y position of the start 
			x1: the x position of the start 
			y2: the y position of the end 
			x2: the x position of the end 

		Returns:
			the added line. 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int) -> Line:
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line, can include alpha value 
			y1: the y position of the start 
			x1: the x position of the start 
			y2: the y position of the end 
			x2: the x position of the end 
			zIndex: the z-index of the line 

		Returns:
			the added line. 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, width: float) -> Line:
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line, can include alpha value 
			y1: the y position of the start 
			width: the width of the line 
			x1: the x position of the start 
			y2: the y position of the end 
			x2: the x position of the end 

		Returns:
			the added line. 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int, width: float) -> Line:
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line, can include alpha value 
			y1: the y position of the start 
			width: the width of the line 
			x1: the x position of the start 
			y2: the y position of the end 
			x2: the x position of the end 
			zIndex: the z-index of the line 

		Returns:
			the added line. 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, width: float, rotation: float) -> Line:
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line, can include alpha value 
			rotation: the rotation (clockwise) of the line (as degrees) 
			y1: the y position of the start 
			width: the width of the line 
			x1: the x position of the start 
			y2: the y position of the end 
			x2: the x position of the end 

		Returns:
			the added line. 
		"""
		pass

	@overload
	def addLine(self, x1: int, y1: int, x2: int, y2: int, color: int, zIndex: int, width: float, rotation: float) -> Line:
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line, can include alpha value 
			rotation: the rotation (clockwise) of the line (as degrees) 
			y1: the y position of the start 
			width: the width of the line 
			x1: the x position of the start 
			y2: the y position of the end 
			x2: the x position of the end 
			zIndex: the z-index of the line 

		Returns:
			the added line. 
		"""
		pass

	@overload
	def removeLine(self, l: Line) -> T:
		"""
		Since: 1.8.4 

		Args:
			l: the line to remove 

		Returns:
			self chaining. 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> Item:
		"""
		Since: 1.2.7 

		Args:
			x: left most corner 
			y: top most corner 
			id: item id 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str) -> Item:
		"""
		Since: 1.4.0 

		Args:
			x: left most corner 
			y: top most corner 
			id: item id 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> Item:
		"""
		Since: 1.2.7 

		Args:
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 
			id: item id 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool) -> Item:
		"""
		Since: 1.4.0 

		Args:
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 
			id: item id 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> Item:
		"""
		Since: 1.2.7 

		Args:
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 
			id: item id 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> Item:
		"""
		Since: 1.4.0 

		Args:
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 
			id: item id 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper) -> Item:
		"""
		Since: 1.2.7 

		Args:
			item: from inventory as helper 
			x: left most corner 
			y: top most corner 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper) -> Item:
		"""
		Since: 1.4.0 

		Args:
			item: from inventory as helper 
			x: left most corner 
			y: top most corner 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool) -> Item:
		"""
		Since: 1.2.7 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool) -> Item:
		"""
		Since: 1.4.0 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> Item:
		"""
		Since: 1.2.7 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> Item:
		"""
		Since: 1.4.0 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def removeItem(self, i: Item) -> T:
		"""
		Since: 1.2.7 

		Args:
			i: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addDraw2D(self, draw2D: Draw2D, x: int, y: int, width: int, height: int) -> Draw2DElement:
		"""Tries to add the given draw2d as a child. Fails if cyclic dependencies are detected.\n
		Since: 1.8.4 

		Args:
			x: the x position on this draw2d 
			width: the width of the given draw2d 
			y: the y position on this draw2d 
			draw2D: the draw2d to add 
			height: the height of the given draw2d 

		Returns:
			a wrapper for the draw2d. 
		"""
		pass

	@overload
	def addDraw2D(self, draw2D: Draw2D, x: int, y: int, width: int, height: int, zIndex: int) -> Draw2DElement:
		"""Tries to add the given draw2d as a child. Fails if cyclic dependencies are detected.\n
		Since: 1.8.4 

		Args:
			x: the x position on this draw2d 
			width: the width of the given draw2d 
			y: the y position on this draw2d 
			draw2D: the draw2d to add 
			height: the height of the given draw2d 
			zIndex: the z-index for the draw2d 

		Returns:
			a wrapper for the draw2d. 
		"""
		pass

	@overload
	def removeDraw2D(self, draw2D: Draw2DElement) -> T:
		"""
		Since: 1.8.4 

		Args:
			draw2D: the draw2d to remove 

		Returns:
			self chaining. 
		"""
		pass

	@overload
	def itemBuilder(self) -> Item_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a builder for an Item . 
		"""
		pass

	@overload
	def itemBuilder(self, item: ItemStackHelper) -> Item_Builder:
		"""
		Since: 1.8.4 

		Args:
			item: the item to use 

		Returns:
			a builder for an Item . 
		"""
		pass

	@overload
	def imageBuilder(self) -> Image_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a builder for an Image . 
		"""
		pass

	@overload
	def imageBuilder(self, id: str) -> Image_Builder:
		"""
		Since: 1.8.4 

		Args:
			id: the id of the image 

		Returns:
			a builder for an Image . 
		"""
		pass

	@overload
	def rectBuilder(self) -> Rect_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a builder for a Rect . 
		"""
		pass

	@overload
	def rectBuilder(self, x: int, y: int, width: int, height: int) -> Rect_Builder:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the rectangle 
			width: the width of the rectangle 
			y: the y position of the rectangle 
			height: the height of the rectangle 

		Returns:
			a builder for a Rect . 
		"""
		pass

	@overload
	def lineBuilder(self) -> Line_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a builder for a Line . 
		"""
		pass

	@overload
	def lineBuilder(self, x1: int, y1: int, x2: int, y2: int) -> Line_Builder:
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the first point 
			x1: the x position of the first point 
			y2: the y position of the second point 
			x2: the x position of the second point 

		Returns:
			a builder for a Line . 
		"""
		pass

	@overload
	def textBuilder(self) -> Text_Builder:
		"""
		Since: 1.8.4 

		Returns:
			a builder for a Text . 
		"""
		pass

	@overload
	def textBuilder(self, text: str) -> Text_Builder:
		"""
		Since: 1.8.4 

		Args:
			text: the text to display 

		Returns:
			a builder for a Text . 
		"""
		pass

	@overload
	def textBuilder(self, text: TextHelper) -> Text_Builder:
		"""
		Since: 1.8.4 

		Args:
			text: the text to display 

		Returns:
			a builder for a Text . 
		"""
		pass

	@overload
	def draw2DBuilder(self, draw2D: Draw2D) -> Draw2DElement_Builder:
		"""
		Since: 1.8.4 

		Args:
			draw2D: the draw2d to add 

		Returns:
			a builder for a Draw2D . 
		"""
		pass

	@overload
	def setOnInit(self, onInit: MethodWrapper) -> T:
		"""
		Since: 1.2.7 

		Args:
			onInit: calls your method as a Consumer IDraw2D#T 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setOnFailInit(self, catchInit: MethodWrapper) -> T:
		"""
		Since: 1.2.7 

		Args:
			catchInit: calls your method as a Consumer String 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def render(self, drawContext: DrawContext) -> None:
		"""internal

		Args:
			drawContext: 
		"""
		pass

	@overload
	def setZIndex(self, zIndex: int) -> None:
		"""
		Since: 1.8.4 

		Args:
			zIndex: 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 
		"""
		pass

	pass





from typing import overload
from typing import Mapping
from .BaseLibrary import BaseLibrary


class FGlobalVars(BaseLibrary):
	""""Global" variables for passing to other contexts. 
An instance of this class is passed to scripts as the 'GlobalVars' variable.\n
	Since: 1.0.4 
	"""
	globalRaw: Mapping[str, object]

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def putInt(self, name: str, i: int) -> int:
		"""Put an Integer into the global variable space.\n
		Since: 1.0.4 

		Args:
			name: 
			i: 
		"""
		pass

	@overload
	def putString(self, name: str, str: str) -> str:
		"""put a String into the global variable space.\n
		Since: 1.0.4 

		Args:
			str: 
			name: 
		"""
		pass

	@overload
	def putDouble(self, name: str, d: float) -> float:
		"""put a Double into the global variable space.\n
		Since: 1.0.8 

		Args:
			d: 
			name: 
		"""
		pass

	@overload
	def putBoolean(self, name: str, b: bool) -> bool:
		"""put a Boolean into the global variable space.\n
		Since: 1.1.7 

		Args:
			b: 
			name: 
		"""
		pass

	@overload
	def putObject(self, name: str, o: object) -> object:
		"""put anything else into the global variable space.\n
		Since: 1.1.7 

		Args:
			name: 
			o: 
		"""
		pass

	@overload
	def getType(self, name: str) -> str:
		"""Returns the type of the defined item in the global variable space as a string.\n
		Since: 1.0.4 

		Args:
			name: 
		"""
		pass

	@overload
	def getInt(self, name: str) -> int:
		"""Gets an Integer from the global variable space.\n
		Since: 1.0.4 

		Args:
			name: 
		"""
		pass

	@overload
	def getAndIncrementInt(self, name: str) -> int:
		"""Gets an Integer from the global variable space. and then increment it there.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getAndDecrementInt(self, name: str) -> int:
		"""Gets an integer from the global variable space. and then decrement it there.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def incrementAndGetInt(self, name: str) -> int:
		"""increment an Integer in the global variable space. then return it.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def decrementAndGetInt(self, name: str) -> int:
		"""decrement an Integer in the global variable space. then return it.\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getString(self, name: str) -> str:
		"""Gets a String from the global variable space\n
		Since: 1.0.4 

		Args:
			name: 
		"""
		pass

	@overload
	def getDouble(self, name: str) -> float:
		"""Gets a Double from the global variable space.\n
		Since: 1.0.8 

		Args:
			name: 
		"""
		pass

	@overload
	def getBoolean(self, name: str) -> bool:
		"""Gets a Boolean from the global variable space.\n
		Since: 1.1.7 

		Args:
			name: 
		"""
		pass

	@overload
	def toggleBoolean(self, name: str) -> bool:
		"""toggles a global boolean and returns its new value\n
		Since: 1.6.5 

		Args:
			name: 
		"""
		pass

	@overload
	def getObject(self, name: str) -> object:
		"""Gets an Object from the global variable space.\n
		Since: 1.1.7 

		Args:
			name: 
		"""
		pass

	@overload
	def remove(self, key: str) -> None:
		"""removes a key from the global variable space.\n
		Since: 1.2.0 

		Args:
			key: 
		"""
		pass

	@overload
	def getRaw(self) -> Mapping[str, object]:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_data_TrackedData_java_lang_Byte_ = TypeVar("net_minecraft_entity_data_TrackedData_java_lang_Byte_")
TrackedData = net_minecraft_entity_data_TrackedData_java_lang_Byte_


class MixinSpellcastingIllagerEntityHelper:
	"""
	Since: 1.8.4 
	"""

	@overload
	def getSpellKey(self) -> TrackedData:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MethodWrapper import MethodWrapper

com_neovisionaries_ws_client_WebSocket = TypeVar("com_neovisionaries_ws_client_WebSocket")
WebSocket = com_neovisionaries_ws_client_WebSocket


class Websocket:
	"""
	"""
	onConnect: MethodWrapper
	onTextMessage: MethodWrapper
	onDisconnect: MethodWrapper
	onError: MethodWrapper
	onFrame: MethodWrapper

	@overload
	def __init__(self, address: str) -> None:
		pass

	@overload
	def __init__(self, address: URL) -> None:
		pass

	@overload
	def connect(self) -> "Websocket":
		"""
		Since: 1.1.9 

		Returns:
			self 
		"""
		pass

	@overload
	def getWs(self) -> WebSocket:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def sendText(self, text: str) -> "Websocket":
		"""
		Since: 1.1.9 

		Args:
			text: 

		Returns:
			self 
		"""
		pass

	@overload
	def close(self) -> "Websocket":
		"""
		Since: 1.1.9 

		Returns:
			self 
		"""
		pass

	@overload
	def close(self, closeCode: int) -> "Websocket":
		"""
		Since: 1.1.9 

		Args:
			closeCode: 

		Returns:
			self 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .AdvancementHelper import AdvancementHelper
from .AdvancementProgressHelper import AdvancementProgressHelper

net_minecraft_advancement_AdvancementManager = TypeVar("net_minecraft_advancement_AdvancementManager")
AdvancementManager = net_minecraft_advancement_AdvancementManager


class AdvancementManagerHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, advancementManager: AdvancementManager) -> None:
		pass

	@overload
	def getAdvancementsForIdentifiers(self) -> Mapping[str, AdvancementHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all advancement ids and their advancement. 
		"""
		pass

	@overload
	def getAdvancements(self) -> List[AdvancementHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all advancements. 
		"""
		pass

	@overload
	def getStartedAdvancements(self) -> List[AdvancementHelper]:
		"""Started advancements are advancements that have been started, so at least one task has been
completed so far, but not fully completed.\n
		Since: 1.8.4 

		Returns:
			a list of all started advancements. 
		"""
		pass

	@overload
	def getMissingAdvancements(self) -> List[AdvancementHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all missing advancements. 
		"""
		pass

	@overload
	def getCompletedAdvancements(self) -> List[AdvancementHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all completed advancements. 
		"""
		pass

	@overload
	def getRootAdvancements(self) -> List[AdvancementHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all the root advancements. 
		"""
		pass

	@overload
	def getSubAdvancements(self) -> List[AdvancementHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all advancements that are not a root. 
		"""
		pass

	@overload
	def getAdvancement(self, identifier: str) -> AdvancementHelper:
		"""
		Since: 1.8.4 

		Args:
			identifier: the identifier of the advancement 

		Returns:
			the advancement for the given identifier. 
		"""
		pass

	@overload
	def getAdvancementsProgress(self) -> Mapping[AdvancementHelper, AdvancementProgressHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all advancements and their progress. 
		"""
		pass

	@overload
	def getAdvancementProgress(self, identifier: str) -> AdvancementProgressHelper:
		"""
		Since: 1.8.4 

		Returns:
			the progress of the given advancement. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .TraceLine import TraceLine
from .EntityHelper import EntityHelper

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_render_BufferBuilder = TypeVar("net_minecraft_client_render_BufferBuilder")
BufferBuilder = net_minecraft_client_render_BufferBuilder


class EntityTraceLine(TraceLine):
	"""
	Since: 1.9.0 
	"""
	dirty: bool
	entity: Entity
	yOffset: float
	shouldRemove: bool

	@overload
	def __init__(self, entity: EntityHelper, color: int, yOffset: float) -> None:
		pass

	@overload
	def __init__(self, entity: EntityHelper, color: int, alpha: int, yOffset: float) -> None:
		pass

	@overload
	def setEntity(self, entity: EntityHelper) -> "EntityTraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setYOffset(self, yOffset: float) -> "EntityTraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def render(self, drawContext: DrawContext, builder: BufferBuilder, tickDelta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IContainerParent import IContainerParent
from .OverlayContainer import OverlayContainer

net_minecraft_client_gui_Element = TypeVar("net_minecraft_client_gui_Element")
Element = net_minecraft_client_gui_Element


class IOverlayParent(IContainerParent):

	@overload
	def closeOverlay(self, overlay: OverlayContainer) -> None:
		pass

	@overload
	def setFocused(self, focused: Element) -> None:
		pass

	@overload
	def getChildOverlay(self) -> OverlayContainer:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .ItemStackHelper import ItemStackHelper

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class EventItemDamage(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	item: ItemStackHelper
	damage: int

	@overload
	def __init__(self, stack: ItemStack, damage: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .RenderElement import RenderElement
from .Alignable import Alignable
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

B = TypeVar("B")
B = B

T = TypeVar("T")
net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class ClickableWidgetHelper(RenderElement, Alignable, Generic[B, T], BaseHelper):
	"""
	Since: 1.0.5 
	"""
	zIndex: int
	tooltips: List[Text]

	@overload
	def __init__(self, btn: T) -> None:
		pass

	@overload
	def __init__(self, btn: T, zIndex: int) -> None:
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.0.5 

		Returns:
			the 'x' coordinate of the button. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.0.5 

		Returns:
			the 'y' coordinate of the button. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> B:
		"""Set the button position.\n
		Since: 1.0.5 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the button. 
		"""
		pass

	@overload
	def setLabel(self, label: str) -> B:
		"""change the text.\n
		Since: 1.0.5, renamed from 'setText' in 1.3.1 

		Args:
			label: 
		"""
		pass

	@overload
	def setLabel(self, helper: TextHelper) -> B:
		"""change the text.\n
		Since: 1.3.1 

		Args:
			helper: 
		"""
		pass

	@overload
	def getLabel(self) -> TextHelper:
		"""
		Since: 1.2.3, renamed fro 'getText' in 1.3.1 

		Returns:
			current button text. 
		"""
		pass

	@overload
	def getActive(self) -> bool:
		"""
		Since: 1.0.5 

		Returns:
			button clickable state. 
		"""
		pass

	@overload
	def setActive(self, t: bool) -> B:
		"""set the button clickable state.\n
		Since: 1.0.5 

		Args:
			t: 
		"""
		pass

	@overload
	def setWidth(self, width: int) -> B:
		"""set the button width.\n
		Since: 1.0.5 

		Args:
			width: 
		"""
		pass

	@overload
	def click(self) -> B:
		"""clicks button\n
		Since: 1.3.1 
		"""
		pass

	@overload
	def click(self, await_: bool) -> B:
		"""clicks button\n
		Since: 1.3.1 

		Args:
			await: should wait for button to finish clicking. 
		"""
		pass

	@overload
	def setTooltip(self, tooltips: List[object]) -> B:
		"""
		Since: 1.8.4 

		Args:
			tooltips: the tooltips to set 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addTooltip(self, tooltip: object) -> B:
		"""
		Since: 1.8.4 

		Args:
			tooltip: the tooltips to add 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def removeTooltip(self, index: int) -> bool:
		"""
		Since: 1.8.4 

		Args:
			index: the index of the tooltip to remove 

		Returns:
			'true' if the tooltip was removed successfully, 'false' otherwise. 
		"""
		pass

	@overload
	def removeTooltip(self, tooltip: TextHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			tooltip: the tooltip to remove 

		Returns:
			'true' if the tooltip was removed successfully, 'false' otherwise. 
		"""
		pass

	@overload
	def getTooltips(self) -> List[TextHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a copy of the tooltips. 
		"""
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> B:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .ColorMapSetting import ColorMapSetting

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class ColorMapSetting_ColorEntry(AbstractMapSettingContainer_MapSettingEntry):

	@overload
	def __init__(self, x: int, y: int, width: int, textRenderer: TextRenderer, parent: ColorMapSetting, key: str, value: List[float]) -> None:
		pass

	@overload
	def convertColorToString(self, color: List[float]) -> str:
		pass

	@overload
	def convertStringToColor(self, color: str) -> List[float]:
		pass

	@overload
	def convertColorToInt(self, color: List[float]) -> int:
		pass

	@overload
	def init(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType

java_io_File = TypeVar("java_io_File")
File = java_io_File


class ScriptTrigger:
	triggerType: ScriptTrigger_TriggerType
	event: str
	scriptFile: str
	enabled: bool
	joined: bool

	@overload
	def __init__(self, triggerType: ScriptTrigger_TriggerType, event: str, scriptFile: File, enabled: bool, joined: bool) -> None:
		pass

	@overload
	def __init__(self, triggerType: ScriptTrigger_TriggerType, event: str, scriptFile: str, enabled: bool, joined: bool) -> None:
		pass

	@overload
	def equals(self, macro: "ScriptTrigger") -> bool:
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def copy(self, m: "ScriptTrigger") -> "ScriptTrigger":
		pass

	@overload
	def copy(self) -> "ScriptTrigger":
		pass

	@overload
	def getTriggerType(self) -> ScriptTrigger_TriggerType:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getEvent(self) -> str:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getScriptFile(self) -> str:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getEnabled(self) -> bool:
		"""
		Since: 1.2.7 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Any
from typing import Mapping
from .BaseEvent import BaseEvent
from .SelectCursor import SelectCursor
from .EditorScreen import EditorScreen
from .TextHelper import TextHelper
from .AutoCompleteSuggestion import AutoCompleteSuggestion
from .MethodWrapper import MethodWrapper
from .TextBuilder import TextBuilder
from .StringHashTrie import StringHashTrie

io_noties_prism4j_Prism4j_Node = TypeVar("io_noties_prism4j_Prism4j_Node")
Prism4j_Node = io_noties_prism4j_Prism4j_Node


class CodeCompileEvent(BaseEvent):
	""""hidden" event for script based code style compiling / linting tasks.
remember to 'consumer.autoWrap()' everything.\n
	Since: 1.3.1 
	"""
	cursor: SelectCursor
	code: str
	language: str
	screen: EditorScreen
	textLines: List[TextHelper]
	autoCompleteSuggestions: List[AutoCompleteSuggestion]
	rightClickActions: MethodWrapper

	@overload
	def __init__(self, code: str, language: str, screen: EditorScreen) -> None:
		pass

	@overload
	def genPrismNodes(self) -> List[Prism4j_Node]:
		"""

		Returns:
			Prism4j's
node list you don't have to use it but if you're not compiling your own...
peek at the code of TextStyleCompiler for the default impl for walking the node tree. 
		"""
		pass

	@overload
	def createMap(self) -> Mapping[Any, Any]:
		"""Easy access to the Map object for use with CodeCompileEvent#rightClickActions

		Returns:
			specifically a LinkedHashMap 
		"""
		pass

	@overload
	def createTextBuilder(self) -> TextBuilder:
		"""more convenient access to TextBuilder

		Returns:
			new instance for use with CodeCompileEvent#textLines 
		"""
		pass

	@overload
	def createSuggestion(self, startIndex: int, suggestion: str) -> AutoCompleteSuggestion:
		pass

	@overload
	def createSuggestion(self, startIndex: int, suggestion: str, displayText: TextHelper) -> AutoCompleteSuggestion:
		"""

		Args:
			displayText: how the text should be displayed in the dropdown, default is suggestion text 
			startIndex: index that is where the suggestion starts from before the already typed part 
			suggestion: complete suggestion including the already typed part 

		Returns:
			a new suggestion object 
		"""
		pass

	@overload
	def createPrefixTree(self) -> StringHashTrie:
		"""prefix tree data structure written for you, it's a bit intensive to add things to, especially how I wrote it, but
lookup times are much better at least on larger data sets,
so create a single copy of this for your static autocompletes and don't be re-creating this every time, store it
in 'globalvars' , probably per language 
or just don't use it, I'm not forcing you to.

		Returns:
			a new StringHashTrie 
		"""
		pass

	@overload
	def getThemeData(self) -> Mapping[str, List[float]]:
		"""

		Returns:
			'key -> hex integer' values for theme data points, this can be used with the prism data for
coloring, just have to use TextBuilder#withColor(int,int,int) on 1.15 and older versions the integer values with be the default color's index so you can directly pass it
to TextBuilder#withColor(int) 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer


class IEventListener:
	NULL: "IEventListener"

	@overload
	def joined(self) -> bool:
		pass

	@overload
	def trigger(self, event: BaseEvent) -> EventContainer:
		pass

	@overload
	def off(self) -> None:
		"""Used for self unregistering events.\n
		Since: 1.8.4 
		"""
		pass

	pass





from typing import overload
from typing import List
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper
from .AbstractHorseEntityHelper import AbstractHorseEntityHelper


class HorseInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def canBeSaddled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the horse can be saddled, 'false' otherwise. 
		"""
		pass

	@overload
	def isSaddled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the horse is saddled, 'false' otherwise. 
		"""
		pass

	@overload
	def getSaddle(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the saddle item. 
		"""
		pass

	@overload
	def hasArmorSlot(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the horse can equip armor, 'false' otherwise. 
		"""
		pass

	@overload
	def getArmor(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the armor item. 
		"""
		pass

	@overload
	def hasChest(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the horse has equipped a chest, 'false' otherwise. 
		"""
		pass

	@overload
	def getInventorySize(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the horse's inventory size. 
		"""
		pass

	@overload
	def getHorseInventory(self) -> List[ItemStackHelper]:
		"""
		Since: 1.8.4 

		Returns:
			a list of items in the horse's inventory. 
		"""
		pass

	@overload
	def getHorse(self) -> AbstractHorseEntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			the horse this inventory belongs to. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .BaseHelper import BaseHelper

U = TypeVar("U")

class StateHelper(Generic[U], BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: U) -> None:
		pass

	@overload
	def toMap(self) -> Mapping[str, str]:
		"""
		Since: 1.8.4 

		Returns:
			a map of the state properties with its identifier and value. 
		"""
		pass

	@overload
	def with_(self, property: str, value: str) -> "StateHelper":
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Any
from .BaseHelper import BaseHelper
from .BlockPosHelper import BlockPosHelper
from .MethodWrapper import MethodWrapper

net_minecraft_world_Heightmap = TypeVar("net_minecraft_world_Heightmap")
Heightmap = net_minecraft_world_Heightmap

java_util_Map_Entry_net_minecraft_world_Heightmap_Type,net_minecraft_world_Heightmap_ = TypeVar("java_util_Map_Entry_net_minecraft_world_Heightmap_Type,net_minecraft_world_Heightmap_")
Map_Entry = java_util_Map_Entry_net_minecraft_world_Heightmap_Type,net_minecraft_world_Heightmap_

net_minecraft_world_chunk_Chunk = TypeVar("net_minecraft_world_chunk_Chunk")
Chunk = net_minecraft_world_chunk_Chunk


class ChunkHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: Chunk) -> None:
		pass

	@overload
	def getStartingBlock(self) -> BlockPosHelper:
		"""
		Since: 1.8.4 

		Returns:
			the first block (0 0 0 coordinate) of this chunk. 
		"""
		pass

	@overload
	def getOffsetBlock(self, xOffset: int, y: int, zOffset: int) -> BlockPosHelper:
		"""The coordinates are relative to the starting chunk position, see ChunkHelper#getStartingBlock() .\n
		Since: 1.8.4 

		Args:
			xOffset: the xOffset offset 
			y: the actual y coordinate 
			zOffset: the zOffset offset 

		Returns:
			the block offset from the starting block of this chunk by xOffset y zOffset. 
		"""
		pass

	@overload
	def getMaxBuildHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum height of this chunk. 
		"""
		pass

	@overload
	def getMinBuildHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the minimum height of this chunk. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of this chunk. 
		"""
		pass

	@overload
	def getTopYAt(self, xOffset: int, zOffset: int, heightmap: Heightmap) -> int:
		"""
		Since: 1.8.4 

		Args:
			heightmap: the heightmap to use 
			xOffset: the xOffset coordinate 
			zOffset: the zOffset coordinate 

		Returns:
			the maximum 'y' position of all blocks inside this chunk. 
		"""
		pass

	@overload
	def getChunkX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the 'x' coordinate (not the world coordinate) of this chunk. 
		"""
		pass

	@overload
	def getChunkZ(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the 'z' coordinate (not the world coordinate) of this chunk. 
		"""
		pass

	@overload
	def getBiome(self, xOffset: int, y: int, zOffset: int) -> str:
		"""
		Since: 1.8.4 

		Args:
			xOffset: the x offset 
			y: the y coordinate 
			zOffset: the z offset 

		Returns:
			the biome at the given position. 
		"""
		pass

	@overload
	def getInhabitedTime(self) -> float:
		"""With an increasing inhabited time, the local difficulty increases and stronger mobs will
spawn. Because the time is cumulative, the more players are in the chunk, the faster the time
will increase.\n
		Since: 1.8.4 

		Returns:
			the cumulative time players have spent inside this chunk. 
		"""
		pass

	@overload
	def getEntities(self) -> List[Any]:
		"""
		Since: 1.8.4 

		Returns:
			all entities inside this chunk. 
		"""
		pass

	@overload
	def getTileEntities(self) -> List[BlockPosHelper]:
		"""
		Since: 1.8.4 

		Returns:
			all tile entity positions inside this chunk. 
		"""
		pass

	@overload
	def forEach(self, includeAir: bool, callback: MethodWrapper) -> "ChunkHelper":
		"""
		Since: 1.8.4 

		Args:
			includeAir: whether to include air blocks or not 
			callback: the callback function 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def containsAny(self, blocks: List[str]) -> bool:
		"""
		Since: 1.8.4 

		Args:
			blocks: the blocks to search for 

		Returns:
			'true' if this chunk contains at least one of the specified blocks, 'false' otherwise. 
		"""
		pass

	@overload
	def containsAll(self, blocks: List[str]) -> bool:
		"""
		Since: 1.8.4 

		Args:
			blocks: the blocks to search for 

		Returns:
			'true' if the chunk contains all the specified blocks, 'false' otherwise. 
		"""
		pass

	@overload
	def getHeightmaps(self) -> List[Map_Entry]:
		"""
		Since: 1.8.4 

		Returns:
			a map of the raw heightmap data. 
		"""
		pass

	@overload
	def getSurfaceHeightmap(self) -> Heightmap:
		"""
		Since: 1.8.4 

		Returns:
			the raw surface heightmap. 
		"""
		pass

	@overload
	def getOceanFloorHeightmap(self) -> Heightmap:
		"""
		Since: 1.8.4 

		Returns:
			the raw ocean floor heightmap. 
		"""
		pass

	@overload
	def getMotionBlockingHeightmap(self) -> Heightmap:
		"""
		Since: 1.8.4 

		Returns:
			the raw motion blocking heightmap. 
		"""
		pass

	@overload
	def getMotionBlockingNoLeavesHeightmap(self) -> Heightmap:
		"""
		Since: 1.8.4 

		Returns:
			the raw motion blocking heightmap without leaves. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .OptionsHelper import OptionsHelper


class OptionsHelper_ChatOptionsHelper:
	parent: OptionsHelper

	@overload
	def __init__(self, OptionsHelper: OptionsHelper) -> None:
		pass

	@overload
	def getParent(self) -> OptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the parent options helper. 
		"""
		pass

	@overload
	def getChatVisibility(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current chat visibility mode. 
		"""
		pass

	@overload
	def setChatVisibility(self, mode: str) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the new chat visibility mode. Must be "FULL", "SYSTEM" or "HIDDEN 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def areColorsShown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if messages can use color codes, 'false' otherwise. 
		"""
		pass

	@overload
	def setShowColors(self, val: bool) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to allow color codes in messages or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def areWebLinksEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if it's allowed to open web links from chat, 'false' otherwise. 
		"""
		pass

	@overload
	def enableWebLinks(self, val: bool) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to allow opening web links from chat or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isWebLinkPromptEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if a warning prompt before opening links should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def enableWebLinkPrompt(self, val: bool) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to show warning prompts before opening links or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatOpacity(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat opacity. 
		"""
		pass

	@overload
	def setChatOpacity(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat opacity 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setTextBackgroundOpacity(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new background opacity for text 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getTextBackgroundOpacity(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current background opacity of text. 
		"""
		pass

	@overload
	def getTextSize(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current text size. 
		"""
		pass

	@overload
	def setTextSize(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new text size 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatLineSpacing(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat line spacing. 
		"""
		pass

	@overload
	def setChatLineSpacing(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat line spacing 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatDelay(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat delay in seconds. 
		"""
		pass

	@overload
	def setChatDelay(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat delay in seconds 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatWidth(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current chat width. 
		"""
		pass

	@overload
	def setChatWidth(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new chat width 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatFocusedHeight(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the focused chat height. 
		"""
		pass

	@overload
	def setChatFocusedHeight(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new focused chat height 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getChatUnfocusedHeight(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the unfocused chat height. 
		"""
		pass

	@overload
	def setChatUnfocusedHeight(self, val: float) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: the new unfocused chat height 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getNarratorMode(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the current narrator mode. 
		"""
		pass

	@overload
	def setNarratorMode(self, mode: str) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			mode: the mode to set the narrator to. Must be either "OFF", "ALL", "CHAT", or
            "SYSTEM" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def areCommandSuggestionsEnabled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if command suggestions are enabled 
		"""
		pass

	@overload
	def enableCommandSuggestions(self, val: bool) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable command suggestions or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def areMatchedNamesHidden(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if messages from blocked users are hidden. 
		"""
		pass

	@overload
	def enableHideMatchedNames(self, val: bool) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to hide messages of blocked users or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isDebugInfoReduced(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if reduced debug info is enabled, 'false' otherwise. 
		"""
		pass

	@overload
	def reduceDebugInfo(self, val: bool) -> "OptionsHelper_ChatOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether to enable reduced debug info or not 

		Returns:
			self for chaining. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseEvent import BaseEvent
from .TextHelper import TextHelper

net_minecraft_client_gui_hud_MessageIndicator = TypeVar("net_minecraft_client_gui_hud_MessageIndicator")
MessageIndicator = net_minecraft_client_gui_hud_MessageIndicator

net_minecraft_network_message_MessageSignatureData = TypeVar("net_minecraft_network_message_MessageSignatureData")
MessageSignatureData = net_minecraft_network_message_MessageSignatureData

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class EventRecvMessage(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	text: TextHelper
	signature: List[float]
	messageType: str

	@overload
	def __init__(self, message: Text, signature: MessageSignatureData, indicator: MessageIndicator) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .BaseHelper import BaseHelper
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .Pos2D import Pos2D
from .TextHelper import TextHelper
from .BlockDataHelper import BlockDataHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper
from .DirectionHelper import DirectionHelper
from .ChunkHelper import ChunkHelper
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
from .PlayerEntityHelper import PlayerEntityHelper
from .VillagerEntityHelper import VillagerEntityHelper
from .MerchantEntityHelper import MerchantEntityHelper
from .LivingEntityHelper import LivingEntityHelper
from .ItemEntityHelper import ItemEntityHelper

net_minecraft_entity_Entity = TypeVar("net_minecraft_entity_Entity")
Entity = net_minecraft_entity_Entity

T = TypeVar("T")

class EntityHelper(Generic[T], BaseHelper):
	"""
	"""

	@overload
	def getPos(self) -> Pos3D:
		"""

		Returns:
			entity position. 
		"""
		pass

	@overload
	def getBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.6.5 

		Returns:
			entity block position. 
		"""
		pass

	@overload
	def getEyePos(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the entity's eye position. 
		"""
		pass

	@overload
	def getChunkPos(self) -> Pos2D:
		"""
		Since: 1.6.5 

		Returns:
			entity chunk coordinates. Since Pos2D only has x and y fields, z coord is y. 
		"""
		pass

	@overload
	def getX(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'x' value of the entity. 
		"""
		pass

	@overload
	def getY(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'y' value of the entity. 
		"""
		pass

	@overload
	def getZ(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'z' value of the entity. 
		"""
		pass

	@overload
	def getEyeHeight(self) -> float:
		"""
		Since: 1.2.8 

		Returns:
			the current eye height offset for the entity. 
		"""
		pass

	@overload
	def getPitch(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'pitch' value of the entity. 
		"""
		pass

	@overload
	def getYaw(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'yaw' value of the entity. 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""
		Since: 1.0.8 [citation needed], returned string until 1.6.4 

		Returns:
			the name of the entity. 
		"""
		pass

	@overload
	def getType(self) -> str:
		"""

		Returns:
			the type of the entity. 
		"""
		pass

	@overload
	def is_(self, types: List[str]) -> bool:
		"""checks if this entity type equals to any of the specified types\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def isGlowing(self) -> bool:
		"""
		Since: 1.1.9 

		Returns:
			if the entity has the glowing effect. 
		"""
		pass

	@overload
	def isInLava(self) -> bool:
		"""
		Since: 1.1.9 

		Returns:
			if the entity is in lava. 
		"""
		pass

	@overload
	def isOnFire(self) -> bool:
		"""
		Since: 1.1.9 

		Returns:
			if the entity is on fire. 
		"""
		pass

	@overload
	def isSneaking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the entity is sneaking, 'false' otherwise. 
		"""
		pass

	@overload
	def isSprinting(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the entity is sprinting, 'false' otherwise. 
		"""
		pass

	@overload
	def getVehicle(self) -> "EntityHelper":
		"""
		Since: 1.1.8 [citation needed] 

		Returns:
			the vehicle of the entity. 
		"""
		pass

	@overload
	def rayTraceBlock(self, distance: float, fluid: bool) -> BlockDataHelper:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def rayTraceEntity(self, distance: int) -> "EntityHelper":
		"""
		Since: 1.9.0 

		Args:
			distance: 
		"""
		pass

	@overload
	def getPassengers(self) -> List["EntityHelper"]:
		"""
		Since: 1.1.8 [citation needed] 

		Returns:
			the entity passengers. 
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper_NBTCompoundHelper:
		"""
		Since: 1.2.8, was a String until 1.5.0 
		"""
		pass

	@overload
	def setCustomName(self, name: TextHelper) -> "EntityHelper":
		"""
		Since: 1.6.4 

		Args:
			name: 
		"""
		pass

	@overload
	def setCustomNameVisible(self, b: bool) -> "EntityHelper":
		"""sets the name to always display\n
		Since: 1.8.0 

		Args:
			b: 
		"""
		pass

	@overload
	def setGlowingColor(self, color: int) -> "EntityHelper":
		"""

		Args:
			color: 
		"""
		pass

	@overload
	def resetGlowingColor(self) -> "EntityHelper":
		"""
		"""
		pass

	@overload
	def getGlowingColor(self) -> int:
		"""warning: affected by setGlowingColor\n
		Since: 1.8.2 

		Returns:
			glow color 
		"""
		pass

	@overload
	def setGlowing(self, val: bool) -> "EntityHelper":
		"""Sets whether the entity is glowing.\n
		Since: 1.1.9 

		Args:
			val: 
		"""
		pass

	@overload
	def resetGlowing(self) -> "EntityHelper":
		"""reset the glowing effect to proper value.\n
		Since: 1.6.3 
		"""
		pass

	@overload
	def isAlive(self) -> bool:
		"""Checks if the entity is still alive.\n
		Since: 1.2.8 
		"""
		pass

	@overload
	def getUUID(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			UUID of the entity, random* if not a player, otherwise the player's uuid. 
		"""
		pass

	@overload
	def getMaxAir(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum amount of air this entity can have. 
		"""
		pass

	@overload
	def getAir(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the amount of air this entity has. 
		"""
		pass

	@overload
	def getSpeed(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			this entity's current speed in blocks per second. 
		"""
		pass

	@overload
	def getFacingDirection(self) -> DirectionHelper:
		"""
		Since: 1.8.4 

		Returns:
			the direction the entity is facing, rounded to the nearest 45 degrees. 
		"""
		pass

	@overload
	def distanceTo(self, entity: "EntityHelper") -> float:
		"""
		Since: 1.8.4 

		Returns:
			the distance between this entity and the specified one. 
		"""
		pass

	@overload
	def distanceTo(self, pos: BlockPosHelper) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the distance between this entity and the specified position. 
		"""
		pass

	@overload
	def distanceTo(self, pos: Pos3D) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the distance between this entity and the specified position. 
		"""
		pass

	@overload
	def distanceTo(self, x: float, y: float, z: float) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the distance between this entity and the specified position. 
		"""
		pass

	@overload
	def getVelocity(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the velocity vector. 
		"""
		pass

	@overload
	def getChunk(self) -> ChunkHelper:
		"""
		Since: 1.8.4 

		Returns:
			the chunk helper for the chunk this entity is in. 
		"""
		pass

	@overload
	def getBiome(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of the biome this entity is in. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def create(self, e: Entity) -> "EntityHelper":
		"""mostly for internal use.

		Args:
			e: mc entity. 

		Returns:
			correct subclass of this. 
		"""
		pass

	@overload
	def asClientPlayer(self) -> ClientPlayerEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asPlayer(self) -> PlayerEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asVillager(self) -> VillagerEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asMerchant(self) -> MerchantEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asLiving(self) -> LivingEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asAnimal(self) -> LivingEntityHelper:
		"""
		Since: 1.8.4 

		Returns:
			this helper as an animal entity helper (mainly for typescript). 
		"""
		pass

	@overload
	def asItem(self) -> ItemEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asServerEntity(self) -> "EntityHelper":
		"""
		Since: 1.8.4 

		Returns:
			the entity as a server entity if an integrated server is running and 'null' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .MethodWrapper import MethodWrapper
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder

T = TypeVar("T")

class ClassBuilder(Generic[T]):
	"""
	Since: 1.6.5 
	"""
	methodWrappers: Mapping[str, MethodWrapper]
	ctClass: CtClass

	@overload
	def __init__(self, name: str, parent: Class, interfaces: List[Class]) -> None:
		pass

	@overload
	def addField(self, fieldType: Class, name: str) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def addField(self, code: str) -> "ClassBuilder":
		"""The code must define the full field, including visibility, type, name and an optional value.
Generic types are not supported and must be explicitly cast in the source code when used.
Annotations are also not supported.
Just like in java, classes from the `java.lang` package don't need a fully qualified name.
Examples are:  'private String name;'  'private java.lang.String name;'  'public java.util.List list = new java.util.ArrayList();'  'static int value = 10;'\n
		Since: 1.8.4 

		Args:
			code: the code for the field 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addMethod(self, returnType: Class, name: str, params: List[Class]) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def addMethod(self, code: str) -> "ClassBuilder":
		"""The code must define the full method, including visibility, return type, name and parameters.
Generic types are not supported as return values or arguments, neither can varargs be used.
Annotations are also not supported.
Just like in java, classes from the `java.lang` package don't need a fully qualified name.
Examples are:  'public Object id(Object obj) { return obj; }'  'private void print(String text) { System.out.println(text); }'  'private static java.util.Map toMap(Object[] keys, Object[] values) {
     java.util.Map map = new java.util.HashMap();
     for (int i = 0; i < keys.length; i++) {
         map.put(keys[i], values[i]);
     }
     return map;
 }'  'public String toString() {
     System.out.println(super.toString());
     return "Hello World!";
 }'\n
		Since: 1.8.4 

		Args:
			code: the code for the method 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addConstructor(self, params: List[Class]) -> "ClassBuilder_ConstructorBuilder":
		pass

	@overload
	def addConstructor(self, code: str) -> "ClassBuilder":
		"""The code must define the full constructor, including visibility and parameters.
Generic types are not supported as arguments, neither can varargs be used.
Annotations are also not supported.
Just like in java, classes from the `java.lang` package don't need a fully qualified name.
To make sure the class can be easily instantiated, the visibility of the constructor should be public.
Examples are:  'public MyClass() { }'  'public MyClass(String text) { System.out.println(text); }'  'protected MyClass(String text, int number) { super(text, number, ""); }'  'public MyClass(String text, int number, String other) {
     this(text, number);
     this.other = other;
}'\n
		Since: 1.8.4 

		Args:
			code: the code for the constructor 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def addClinit(self) -> "ClassBuilder_ConstructorBuilder":
		pass

	@overload
	def addAnnotation(self, type: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def finishBuildAndFreeze(self) -> Class:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

java_io_Serializable = TypeVar("java_io_Serializable")
Serializable = java_io_Serializable

E = TypeVar("E")
E = E

java_util_AbstractSet_E_ = TypeVar("java_util_AbstractSet_E_")
AbstractSet = java_util_AbstractSet_E_


class SynchronizedWeakHashSet(Serializable, Generic[E], AbstractSet):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def size(self) -> int:
		pass

	@overload
	def contains(self, o: object) -> bool:
		pass

	@overload
	def add(self, o: E) -> bool:
		pass

	@overload
	def remove(self, o: object) -> bool:
		pass

	@overload
	def clear(self) -> None:
		pass

	@overload
	def iterator(self) -> iter:
		pass

	pass





from typing import overload
from typing import TypeVar

com_mojang_brigadier_tree_CommandNode_S_ = TypeVar("com_mojang_brigadier_tree_CommandNode_S_")
CommandNode = com_mojang_brigadier_tree_CommandNode_S_


class CommandNodeAccessor:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def remove(self, parent: CommandNode, name: str) -> CommandNode:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .BasicFilter import BasicFilter

T = TypeVar("T")

class StringifyFilter(Generic[T], BasicFilter):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, operation: str) -> None:
		pass

	@overload
	def addOption(self, toAdd: str) -> "StringifyFilter":
		pass

	@overload
	def addOption(self, toAdd: List[str]) -> "StringifyFilter":
		pass

	@overload
	def removeOption(self, toRemove: str) -> "StringifyFilter":
		pass

	@overload
	def removeOption(self, toRemove: List[str]) -> "StringifyFilter":
		pass

	@overload
	def apply(self, obj: object) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

java_util_function_Function_java_lang_Object[],java_lang_Object_ = TypeVar("java_util_function_Function_java_lang_Object[],java_lang_Object_")
Function = java_util_function_Function_java_lang_Object[],java_lang_Object_

T = TypeVar("T")

class ProxyBuilder_ProxyReference(Generic[T]):
	self: T
	parent: Function

	@overload
	def __init__(self, self: T, parent: Function) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .BossBarHelper import BossBarHelper

net_minecraft_client_gui_hud_ClientBossBar = TypeVar("net_minecraft_client_gui_hud_ClientBossBar")
ClientBossBar = net_minecraft_client_gui_hud_ClientBossBar

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID


class EventBossbar(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	bossBar: BossBarHelper
	uuid: str
	type: str

	@overload
	def __init__(self, type: str, uuid: UUID, bossBar: ClientBossBar) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .ItemStackHelper import ItemStackHelper
from .Inventory import Inventory

net_minecraft_client_gui_screen_ingame_HandledScreen__ = TypeVar("net_minecraft_client_gui_screen_ingame_HandledScreen__")
HandledScreen = net_minecraft_client_gui_screen_ingame_HandledScreen__

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack


class EventSlotUpdate(BaseEvent):
	"""
	Since: 1.9.0 
	"""
	type: str
	slot: int
	oldStack: ItemStackHelper
	newStack: ItemStackHelper

	@overload
	def __init__(self, screen: HandledScreen, type: str, slot: int, oldStack: ItemStack, newStack: ItemStack) -> None:
		pass

	@overload
	def getInventory(self) -> Inventory:
		"""

		Returns:
			inventory associated with the event 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .Scrollbar import Scrollbar
from .SettingsOverlay import SettingsOverlay
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class AbstractSettingContainer(MultiElementContainer):
	group: List[str]
	scroll: Scrollbar

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: SettingsOverlay, group: List[str]) -> None:
		pass

	@overload
	def addSetting(self, setting: SettingsOverlay_SettingField) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper
from .BlockPosHelper import BlockPosHelper
from .BlockStateHelper import BlockStateHelper

net_minecraft_entity_FallingBlockEntity = TypeVar("net_minecraft_entity_FallingBlockEntity")
FallingBlockEntity = net_minecraft_entity_FallingBlockEntity


class FallingBlockEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FallingBlockEntity) -> None:
		pass

	@overload
	def getOriginBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.8.4 

		Returns:
			the block position this block is falling from. 
		"""
		pass

	@overload
	def getBlockState(self) -> BlockStateHelper:
		"""
		Since: 1.8.4 

		Returns:
			the block state of this falling block. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set

net_minecraft_client_option_KeyBinding = TypeVar("net_minecraft_client_option_KeyBinding")
KeyBinding = net_minecraft_client_option_KeyBinding

net_minecraft_client_util_InputUtil_Key = TypeVar("net_minecraft_client_util_InputUtil_Key")
InputUtil_Key = net_minecraft_client_util_InputUtil_Key


class FKeyBind_KeyTracker:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def press(self, key: InputUtil_Key) -> None:
		pass

	@overload
	def press(self, bind: KeyBinding) -> None:
		pass

	@overload
	def unpress(self, key: InputUtil_Key) -> None:
		pass

	@overload
	def unpress(self, bind: KeyBinding) -> None:
		pass

	@overload
	def getPressedKeys(self) -> Set[str]:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MobEntityHelper import MobEntityHelper

T = TypeVar("T")

class IllagerEntityHelper(Generic[T], MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def isCelebrating(self) -> bool:
		pass

	@overload
	def getState(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_network_ClientPlayerInteractionManager = TypeVar("net_minecraft_client_network_ClientPlayerInteractionManager")
ClientPlayerInteractionManager = net_minecraft_client_network_ClientPlayerInteractionManager

net_minecraft_client_gui_screen_DownloadingTerrainScreen_WorldEntryReason = TypeVar("net_minecraft_client_gui_screen_DownloadingTerrainScreen_WorldEntryReason")
DownloadingTerrainScreen_WorldEntryReason = net_minecraft_client_gui_screen_DownloadingTerrainScreen_WorldEntryReason

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_client_gui_screen_Screen = TypeVar("net_minecraft_client_gui_screen_Screen")
Screen = net_minecraft_client_gui_screen_Screen

net_minecraft_client_world_ClientWorld = TypeVar("net_minecraft_client_world_ClientWorld")
ClientWorld = net_minecraft_client_world_ClientWorld


class MixinMinecraftClient:
	currentScreen: Screen
	interactionManager: ClientPlayerInteractionManager

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def setScreen(self, screen: Screen) -> None:
		pass

	@overload
	def onJoinWorld(self, world: ClientWorld, worldEntryReason: DownloadingTerrainScreen_WorldEntryReason, ci: CallbackInfo) -> None:
		pass

	@overload
	def onOpenScreen(self, screen: Screen, info: CallbackInfo) -> None:
		pass

	@overload
	def afterOpenScreen(self, screen: Screen, info: CallbackInfo) -> None:
		pass

	@overload
	def onDisconnect(self, s: Screen, transferring: bool, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import Mapping


class CustomImage:
	"""
	Since: 1.8.4 
	"""
	IMAGES: Mapping[str, "CustomImage"]

	@overload
	def __init__(self, image: BufferedImage) -> None:
		pass

	@overload
	def __init__(self, image: BufferedImage, name: str) -> None:
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of this image. 
		"""
		pass

	@overload
	def loadImage(self, path: str) -> BufferedImage:
		"""The image can be used with the drawImage methods to draw it onto this image.\n
		Since: 1.8.4 

		Args:
			path: the path to the image, relative to the jsMacros config folder 

		Returns:
			an image from the given path. 
		"""
		pass

	@overload
	def loadImage(self, path: str, x: int, y: int, width: int, height: int) -> BufferedImage:
		"""Loads the image from the given path and returns a subimage of it from the given positions.
The image can be used with the drawImage methods to draw it onto this image.\n
		Since: 1.8.4 

		Args:
			path: the path to the image, relative to the jsMacros config folder 
			x: the x position to get the subimage from 
			width: the width of the subimage 
			y: the y position to get the subimage from 
			height: the height of the subimage 

		Returns:
			the cropped image from the given path. 
		"""
		pass

	@overload
	def update(self) -> "CustomImage":
		"""Updates the texture to be drawn with the contents of this image. Any changes made to this
image will only be displayed after calling this method. The method must not be called after
each change, but rather when the image is finished being changed.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def saveImage(self, path: str, fileName: str) -> "CustomImage":
		"""Saves this image to the given path. The file will be saved as a png.\n
		Since: 1.8.4 

		Args:
			path: the path to the image, relative to the jsMacros config folder 
			fileName: the file name of the image, without the extension 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getIdentifier(self) -> str:
		"""The identifier should be used with any buttons and textures in the draw2D and other classes,
which require an identifier.\n
		Since: 1.8.4 

		Returns:
			the identifier of this image. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""The width is a constant and will not change.\n
		Since: 1.8.4 

		Returns:
			the width of this image. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""The height is a constant and will not change.\n
		Since: 1.8.4 

		Returns:
			the height of this image. 
		"""
		pass

	@overload
	def getImage(self) -> BufferedImage:
		"""
		Since: 1.8.4 

		Returns:
			the internal BufferedImage of this image, which all updates are made to. 
		"""
		pass

	@overload
	def getPixel(self, x: int, y: int) -> int:
		"""The color is in the ARGB format.\n
		Since: 1.8.4 

		Args:
			x: the x position to get the color from 
			y: the y position to get the color from 

		Returns:
			the color at the given position. 
		"""
		pass

	@overload
	def setPixel(self, x: int, y: int, argb: int) -> "CustomImage":
		"""The color is in the ARGB format.\n
		Since: 1.8.4 

		Args:
			argb: the ARGB value to set the pixel to 
			x: the x position to set the color at 
			y: the y position to set the color at 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawImage(self, img: Image, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			img: the image to draw onto this image 
			x: the x position to draw the image at 
			width: the width of the image to draw 
			y: the y position to draw the image at 
			height: the height of the image to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawImage(self, img: Image, x: int, y: int, width: int, height: int, sourceX: int, sourceY: int, sourceWidth: int, sourceHeight: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			sourceX: the x position of the subimage to draw 
			img: the image to draw onto this image 
			sourceY: the y position of the subimage to draw 
			sourceWidth: the width of the subimage to draw 
			x: the x position to draw the image at 
			width: the width of the image to draw 
			y: the y position to draw the image at 
			sourceHeight: the height of the subimage to draw 
			height: the height of the image to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getGraphicsColor(self) -> int:
		"""The color is a rgb value which is used for draw and fill operations.\n
		Since: 1.8.4 

		Returns:
			the graphics current rgb color. 
		"""
		pass

	@overload
	def setGraphicsColor(self, color: int) -> "CustomImage":
		"""The color is a rgb value which is used for draw and fill operations.\n
		Since: 1.8.4 

		Args:
			color: the rgb color to use for graphics operations 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def translate(self, x: int, y: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the origin point 
			y: the y position of the origin point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def clipRect(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""

		Args:
			x: the x coordinate of the rectangle to intersect the clip with 
			width: the width of the rectangle to intersect the clip with 
			y: the y coordinate of the rectangle to intersect the clip with 
			height: the height of the rectangle to intersect the clip with 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setClip(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate of the new clip rectangle 
			width: the width of the new clip rectangle 
			y: the y coordinate of the new clip rectangle 
			height: the height of the new clip rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setPaintMode(self) -> "CustomImage":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setXorMode(self, color: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			color: the color to use for the xor operation 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getClipBounds(self) -> Rectangle:
		"""
		Since: 1.8.4 

		Returns:
			an array with the bounds of the current clip. 
		"""
		pass

	@overload
	def copyArea(self, x: int, y: int, width: int, height: int, dx: int, dy: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			dx: the offset to the x position to copy to 
			dy: the offset to the y position to copy to 
			x: the x position to copy from 
			width: the width of the area to copy 
			y: the y position to copy from 
			height: the height of the area to copy 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawLine(self, x1: int, y1: int, x2: int, y2: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			y1: the first y position of the line 
			x1: the first x position of the line 
			y2: the second y position of the line 
			x2: the second x position of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawRect(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the rectangle 
			width: the width of the rectangle 
			y: the y position of the rectangle 
			height: the height of the rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillRect(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the rectangle 
			width: the width of the rectangle 
			y: the y position of the rectangle 
			height: the height of the rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def clearRect(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the rectangle 
			width: the width of the rectangle 
			y: the y position of the rectangle 
			height: the height of the rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def clearRect(self, x: int, y: int, width: int, height: int, color: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			color: the rgb color to fill the rectangle with 
			x: the x position of the rectangle 
			width: the width of the rectangle 
			y: the y position of the rectangle 
			height: the height of the rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawRoundRect(self, x: int, y: int, width: int, height: int, arcWidth: int, arcHeight: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			arcHeight: the vertical diameter of the arc at the four corners 
			arcWidth: the horizontal diameter of the arc at the four corners 
			x: the x position to draw the rectangle at 
			width: the width of the rectangle 
			y: the y position to draw the rectangle at 
			height: the height of the rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillRoundRect(self, x: int, y: int, width: int, height: int, arcWidth: int, arcHeight: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			arcHeight: the vertical diameter of the arc at the four corners 
			arcWidth: the horizontal diameter of the arc at the four corners 
			x: the x position to draw the rectangle at 
			width: the width of the rectangle 
			y: the y position to draw the rectangle at 
			height: the height of the rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def draw3DRect(self, x: int, y: int, width: int, height: int, raised: bool) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position to draw the 3D rectangle at 
			width: the width of the 3D rectangle 
			raised: whether the rectangle should be raised above the surface or etched into the
              surface 
			y: the y position to draw the 3D rectangle at 
			height: the height of the 3D rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fill3DRect(self, x: int, y: int, width: int, height: int, raised: bool) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position to draw the 3D rectangle at 
			width: the width of the 3D rectangle 
			raised: whether the rectangle should be raised above the surface or etched into the
              surface 
			y: the y position to draw the 3D rectangle at 
			height: the height of the 3D rectangle 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawOval(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position to draw the oval at 
			width: the width of the oval 
			y: the y position to draw the oval at 
			height: the height of the oval 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillOval(self, x: int, y: int, width: int, height: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position to draw the oval at 
			width: the width of the oval 
			y: the y position to draw the oval at 
			height: the height of the oval 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawArc(self, x: int, y: int, width: int, height: int, startAngle: int, arcAngle: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			startAngle: the beginning angle 
			x: the x position to draw the arc at 
			width: the width of the arc 
			y: the y position to draw the arc at 
			arcAngle: the angular extent of the arc, relative to the start angle 
			height: the height of the arc 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillArc(self, x: int, y: int, width: int, height: int, startAngle: int, arcAngle: int) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			startAngle: the beginning angle 
			x: the x position to draw the arc at 
			width: the width of the arc 
			y: the y position to draw the arc at 
			arcAngle: the angular extent of the arc, relative to the start angle 
			height: the height of the arc 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawPolygonLine(self, pointsX: List[int], pointsY: List[int]) -> "CustomImage":
		"""The x and y array must have the same length and order for the points.\n
		Since: 1.8.4 

		Args:
			pointsY: an array of all y positions of the points in the polygon 
			pointsX: an array of all x positions of the points in the polygon 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawPolygon(self, pointsX: List[int], pointsY: List[int]) -> "CustomImage":
		"""The x and y array must have the same length and order for the points.\n
		Since: 1.8.4 

		Args:
			pointsY: an array of all y positions of the points in the polygon 
			pointsX: an array of all x positions of the points in the polygon 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def fillPolygon(self, pointsX: List[int], pointsY: List[int]) -> "CustomImage":
		"""The x and y array must have the same length and order for the points.\n
		Since: 1.8.4 

		Args:
			pointsY: an array of all y positions of the points in the polygon 
			pointsX: an array of all x positions of the points in the polygon 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def drawString(self, x: int, y: int, text: str) -> "CustomImage":
		"""
		Since: 1.8.4 

		Args:
			x: the x position to draw the string at 
			y: the y position to draw the string at 
			text: the text to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getStringWidth(self, toAnalyze: str) -> int:
		"""
		Since: 1.8.4 

		Args:
			toAnalyze: the string to analyze 

		Returns:
			the width of the string for the current font in pixels 
		"""
		pass

	@overload
	def createWidget(self, width: int, height: int, name: str) -> "CustomImage":
		pass

	@overload
	def createWidget(self, path: str, name: str) -> "CustomImage":
		pass

	@overload
	def nativeARGBFlip(self, argb: int) -> int:
		"""Minecraft textures use an ABGR format for some reason.\n
		Since: 1.8.4 

		Args:
			argb: the argb color to transform 

		Returns:
			the abgr argb for the given argb color. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_TntEntity = TypeVar("net_minecraft_entity_TntEntity")
TntEntity = net_minecraft_entity_TntEntity


class TntEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: TntEntity) -> None:
		pass

	@overload
	def getRemainingTime(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the remaining time until this TNT explodes. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .IOverlayParent import IOverlayParent
from .MultiElementContainer import MultiElementContainer
from .Scrollbar import Scrollbar

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_gui_Element = TypeVar("net_minecraft_client_gui_Element")
Element = net_minecraft_client_gui_Element

net_minecraft_client_gui_widget_ClickableWidget = TypeVar("net_minecraft_client_gui_widget_ClickableWidget")
ClickableWidget = net_minecraft_client_gui_widget_ClickableWidget

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class OverlayContainer(IOverlayParent, MultiElementContainer):
	savedBtnStates: Mapping[ClickableWidget, bool]
	scroll: Scrollbar

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: IOverlayParent) -> None:
		pass

	@overload
	def remove(self, btn: Element) -> None:
		pass

	@overload
	def openOverlay(self, overlay: "OverlayContainer") -> None:
		pass

	@overload
	def getFirstOverlayParent(self) -> IOverlayParent:
		pass

	@overload
	def openOverlay(self, overlay: "OverlayContainer", disableButtons: bool) -> None:
		pass

	@overload
	def getChildOverlay(self) -> "OverlayContainer":
		pass

	@overload
	def closeOverlay(self, overlay: "OverlayContainer") -> None:
		pass

	@overload
	def setFocused(self, focused: Element) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		"""

		Returns:
			true if should be handled by overlay 
		"""
		pass

	@overload
	def close(self) -> None:
		pass

	@overload
	def onClose(self) -> None:
		pass

	@overload
	def renderBackground(self, drawContext: DrawContext) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class AutoCompleteSuggestion:
	startIndex: int
	suggestion: str
	displayText: Text

	@overload
	def __init__(self, startIndex: int, suggestion: str) -> None:
		pass

	@overload
	def __init__(self, startIndex: int, suggestion: str, displayText: Text) -> None:
		pass

	pass


